@@ -50,6 +50,14 @@ enable_infin_ast = False # right now infin_ast does not pick up classes defined
 def num_threads():
     return 8
 
+def list_dir_recursively(root, array_of_files):
+    for file in os.listdir(root):
+        if (os.path.isfile(os.path.join(root, file))):
+            if (not file.startswith('USA_all')):
+                array_of_files.append(os.path.join(root, file))
+        else:
+            list_dir_recursively(os.path.join(root, file), array_of_files)
+
 class FuncLister(ast.NodeVisitor):
     def __init__(self, glbs):
         self.glbs = glbs;
@@ -490,6 +498,7 @@ def actually_run_transformation(client, is_pandas_df, bucketname,\
     except Exception as e:
         status_str = str(e)
         info("Execution of global statics failed. status_str=" + status_str)
+        raise
     else:
         status_str = 'Success'
     # print('Globals=')
@@ -576,6 +585,7 @@ def read_and_xform_one_object(client, bucketname,\
             status_str = str(e)
             info("Execution of global statics failed for " + parentdir\
                     + ". status_str=" + status_str)
+            raise
         else:
             status_str = 'Success'
         # print('Globals=')
